@@ -2,7 +2,7 @@ package Log::Defer;
 
 use strict;
 
-our $VERSION = '0.311';
+our $VERSION = '0.312';
 
 use Time::HiRes;
 use Carp qw/croak/;
@@ -451,6 +451,16 @@ Sometimes it's useful to create a "child logger" Log::Defer object which is late
 This technique is used in L<AnyEvent::Task> so that worker processes can log messages using Log::Defer and these are then merged into a client process's existing logger object.
 
 
+=head1 ALTERNATE IMPLEMENTATIONS
+
+Michael Pucyk's Python implementation: L<LogDefer Python module|https://github.com/mikep/LogDefer>
+
+Doug Hoyte's C++ implementation: L<LogDefer-CXX|https://github.com/hoytech/LogDefer-CXX>
+
+Richard Farr's D implementation: L<LogDefer-D|https://github.com/rfarr/LogDefer-D>
+
+Mark Jubenville's Javascript implementation: L<log-defer|https://github.com/ioncache/log-defer>
+
 
 =head1 SEE ALSO
 
@@ -458,13 +468,11 @@ L<Log::Defer github repo|https://github.com/hoytech/Log-Defer>
 
 One way to visualize logs created by this module is with the command-line script L<log-defer-viz>
 
-Michael Pucyk has created a Python implementation for the Log::Defer format: L<LogDefer Python module|https://github.com/mikep/LogDefer>
-
 As mentioned above, this module doesn't itself log messages to disk so you still must use some other module to record your log messages. There are many libraries on CPAN that can do this and there should be at least one that fits your requirements. Some examples are: L<Sys::Syslog>, L<Log::Dispatch>, L<Log::Handler>, L<Log::Log4perl>, L<Log::Fast>, L<AnyEvent::Log>.
 
 Additionally, this module doesn't provide any official serialization format. There are many choices for this, including L<JSON::XS> (JSON is the only format currently supported by L<log-defer-viz>), L<Sereal>, L<Storable>, and L<Data::MessagePack>.
 
-Currently the timestamp generation system is hard-coded to C<Time::HiRes::time>. You should be aware of some caveats related to non-monotonous clocks that are discussed in L<Time::HiRes>.
+Currently the timestamp generation system is hard-coded to C<Time::HiRes::time>. You should be aware of some caveats related to non-monotonic clocks that are discussed in L<Time::HiRes>.
 
 
 
@@ -474,7 +482,7 @@ Doug Hoyte, C<< <doug@hcsw.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2014 Doug Hoyte.
+Copyright 2012-2016 Doug Hoyte.
 
 This module is licensed under the same terms as perl itself.
 
